@@ -1,5 +1,5 @@
 # internal modules
-from termkeymonitor.simple import cli
+from termkeymonitor.rich import cli
 
 if __name__ == "__main__":
     cli()
